@@ -7,7 +7,7 @@ pub struct ArrayObject {
 }
 
 impl MonoVoidPtr for ArrayObject {
-    fn mono_void_ptr(self) -> *mut c_void {
+    fn as_void_ptr(self) -> *mut c_void {
         self.mono_array_object as *mut c_void
     }
 }
